# User Guide

Welcome to the DiracX user guide. This page gives an overview of how use DIRAC to access compute and storage available on the grid. Before you get started it's important that you know which installation you'll be interacting with. You can find some guidance for that in the [known installations](./reference/known-installations.md).

If instead:

- You are an installation admin looking to install, manage or debug your DiracX installation. See the [Administrator Guide](../admin/index.md).
- You are looking to develop software which uses DiracX programmatically, e.g. to submit jobs, check out the user documentation on [programmatic access](../user/reference/programmatic-usage/index.md).
- You want to learn how to develop for DiracX, check the [Developer Guide](../dev/index.md)
- You already know how to manage DiracX and are looking for specific information, see the sidebar on the left for more specific or in-depth documentation.
